@@ -2,14 +2,16 @@ from pathlib import Path
 import responses  # type: ignore
 import json
 import gzip
+import os
 from tests.cli_test_case import CliTestCase
-
+from unittest import mock
 
 class GoogleTestTest(CliTestCase):
     test_files_dir = Path(__file__).parent.joinpath(
         '../data/googletest/').resolve()
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset(self):
         # I use "ctest -N" to get this list.
         pipe = """FooTest.
@@ -28,33 +30,34 @@ class GoogleTestTest(CliTestCase):
         self.assert_json_orderless_equal(expected, payload)
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_test_googletest(self):
         result = self.cli('record', 'tests',  '--session', self.session,
                           'googletest', str(self.test_files_dir) + "/")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[1].request.body)).decode())
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
         expected = self.load_json_from_file(
             self.test_files_dir.joinpath('record_test_result.json'))
 
         self.assert_json_orderless_equal(expected, payload)
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_failed_test_googletest(self):
         # ./test_a --gtest_output=xml:output.xml
         result = self.cli('record', 'tests',  '--session', self.session,
                           'googletest', str(self.test_files_dir) + "/fail/")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[1].request.body)).decode())
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
         expected = self.load_json_from_file(
             self.test_files_dir.joinpath('fail/record_test_result.json'))
 
         self.assert_json_orderless_equal(expected, payload)
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_empty_dir(self):
         path = 'latest/gtest_*_results.xml'
         result = self.cli('record', 'tests',  '--session', self.session,
