@@ -3,6 +3,7 @@ from unittest import mock
 import responses  # type: ignore
 import json
 import gzip
+import os
 from tests.cli_test_case import CliTestCase
 
 
@@ -11,13 +12,13 @@ class RobotTest(CliTestCase):
         '../data/robot/').resolve()
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset(self):
         result = self.cli('subset', '--target', '10%', '--session',
                           self.session, 'robot', str(self.test_files_dir) + "/dryrun.xml")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(gzip.decompress(
-            responses.calls[0].request.body).decode())
+        payload = json.loads(gzip.decompress(responses.calls[0].request.body).decode())
 
         expected = self.load_json_from_file(
             self.test_files_dir.joinpath('subset_result.json'))
@@ -25,14 +26,14 @@ class RobotTest(CliTestCase):
         self.assert_json_orderless_equal(expected, payload)
 
     @ responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_test(self):
 
         result = self.cli('record', 'tests',  '--session', self.session,
                           'robot', str(self.test_files_dir) + "/output.xml")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[1].request.body)).decode())
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
 
         for e in payload["events"]:
             del e["created_at"]
